# Generated by Django 3.1.8 on 2021-05-11 16:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('custom_tag', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='PageTag',
        ),
    ]
